package Bundle::Locale::CLDR::Unitednations;

use version;

our $VERSION = version->declare('v0.46.0');

=head1 NAME

Bundle::Locale::CLDR::Unitednations

=head1 CONTENTS

Locale::CLDR::Locales::Aa 0.46.0

Locale::CLDR::Locales::Ab 0.46.0

Locale::CLDR::Locales::Af 0.46.0

Locale::CLDR::Locales::Ak 0.46.0

Locale::CLDR::Locales::Am 0.46.0

Locale::CLDR::Locales::An 0.46.0

Locale::CLDR::Locales::Ar 0.46.0

Locale::CLDR::Locales::As 0.46.0

Locale::CLDR::Locales::Az 0.46.0

Locale::CLDR::Locales::Ba 0.46.0

Locale::CLDR::Locales::Be 0.46.0

Locale::CLDR::Locales::Bg 0.46.0

Locale::CLDR::Locales::Bm 0.46.0

Locale::CLDR::Locales::Bn 0.46.0

Locale::CLDR::Locales::Bo 0.46.0

Locale::CLDR::Locales::Br 0.46.0

Locale::CLDR::Locales::Bs 0.46.0

Locale::CLDR::Locales::Ca 0.46.0

Locale::CLDR::Locales::Ce 0.46.0

Locale::CLDR::Locales::Co 0.46.0

Locale::CLDR::Locales::Cs 0.46.0

Locale::CLDR::Locales::Cu 0.46.0

Locale::CLDR::Locales::Cv 0.46.0

Locale::CLDR::Locales::Cy 0.46.0

Locale::CLDR::Locales::Da 0.46.0

Locale::CLDR::Locales::De 0.46.0

Locale::CLDR::Locales::Dv 0.46.0

Locale::CLDR::Locales::Dz 0.46.0

Locale::CLDR::Locales::Ee 0.46.0

Locale::CLDR::Locales::El 0.46.0

Locale::CLDR::Locales::Es 0.46.0

Locale::CLDR::Locales::Et 0.46.0

Locale::CLDR::Locales::Eu 0.46.0

Locale::CLDR::Locales::Fa 0.46.0

Locale::CLDR::Locales::Ff 0.46.0

Locale::CLDR::Locales::Fi 0.46.0

Locale::CLDR::Locales::Fo 0.46.0

Locale::CLDR::Locales::Fr 0.46.0

Locale::CLDR::Locales::Fy 0.46.0

Locale::CLDR::Locales::Ga 0.46.0

Locale::CLDR::Locales::Gd 0.46.0

Locale::CLDR::Locales::Gl 0.46.0

Locale::CLDR::Locales::Gn 0.46.0

Locale::CLDR::Locales::Gu 0.46.0

Locale::CLDR::Locales::Ha 0.46.0

Locale::CLDR::Locales::He 0.46.0

Locale::CLDR::Locales::Hi 0.46.0

Locale::CLDR::Locales::Hr 0.46.0

Locale::CLDR::Locales::Hu 0.46.0

Locale::CLDR::Locales::Hy 0.46.0

Locale::CLDR::Locales::Id 0.46.0

Locale::CLDR::Locales::Ie 0.46.0

Locale::CLDR::Locales::Ig 0.46.0

Locale::CLDR::Locales::Ii 0.46.0

Locale::CLDR::Locales::Is 0.46.0

Locale::CLDR::Locales::It 0.46.0

Locale::CLDR::Locales::Iu 0.46.0

Locale::CLDR::Locales::Ja 0.46.0

Locale::CLDR::Locales::Jv 0.46.0

Locale::CLDR::Locales::Ka 0.46.0

Locale::CLDR::Locales::Ki 0.46.0

Locale::CLDR::Locales::Kk 0.46.0

Locale::CLDR::Locales::Km 0.46.0

Locale::CLDR::Locales::Kn 0.46.0

Locale::CLDR::Locales::Ko 0.46.0

Locale::CLDR::Locales::Ks 0.46.0

Locale::CLDR::Locales::Ku 0.46.0

Locale::CLDR::Locales::Kw 0.46.0

Locale::CLDR::Locales::Ky 0.46.0

Locale::CLDR::Locales::Lb 0.46.0

Locale::CLDR::Locales::Lg 0.46.0

Locale::CLDR::Locales::Ln 0.46.0

Locale::CLDR::Locales::Lo 0.46.0

Locale::CLDR::Locales::Lt 0.46.0

Locale::CLDR::Locales::Lu 0.46.0

Locale::CLDR::Locales::Lv 0.46.0

Locale::CLDR::Locales::Mg 0.46.0

Locale::CLDR::Locales::Mi 0.46.0

Locale::CLDR::Locales::Mk 0.46.0

Locale::CLDR::Locales::Ml 0.46.0

Locale::CLDR::Locales::Mn 0.46.0

Locale::CLDR::Locales::Mr 0.46.0

Locale::CLDR::Locales::Ms 0.46.0

Locale::CLDR::Locales::Mt 0.46.0

Locale::CLDR::Locales::My 0.46.0

Locale::CLDR::Locales::Nb 0.46.0

Locale::CLDR::Locales::Nd 0.46.0

Locale::CLDR::Locales::Ne 0.46.0

Locale::CLDR::Locales::Nl 0.46.0

Locale::CLDR::Locales::Nn 0.46.0

Locale::CLDR::Locales::No 0.46.0

Locale::CLDR::Locales::Nr 0.46.0

Locale::CLDR::Locales::Nv 0.46.0

Locale::CLDR::Locales::Ny 0.46.0

Locale::CLDR::Locales::Oc 0.46.0

Locale::CLDR::Locales::Om 0.46.0

Locale::CLDR::Locales::Or 0.46.0

Locale::CLDR::Locales::Os 0.46.0

Locale::CLDR::Locales::Pa 0.46.0

Locale::CLDR::Locales::Pl 0.46.0

Locale::CLDR::Locales::Ps 0.46.0

Locale::CLDR::Locales::Pt 0.46.0

Locale::CLDR::Locales::Qu 0.46.0

Locale::CLDR::Locales::Rm 0.46.0

Locale::CLDR::Locales::Rn 0.46.0

Locale::CLDR::Locales::Ro 0.46.0

Locale::CLDR::Locales::Ru 0.46.0

Locale::CLDR::Locales::Rw 0.46.0

Locale::CLDR::Locales::Sa 0.46.0

Locale::CLDR::Locales::Sc 0.46.0

Locale::CLDR::Locales::Sd 0.46.0

Locale::CLDR::Locales::Se 0.46.0

Locale::CLDR::Locales::Sg 0.46.0

Locale::CLDR::Locales::Si 0.46.0

Locale::CLDR::Locales::Sk 0.46.0

Locale::CLDR::Locales::Sl 0.46.0

Locale::CLDR::Locales::Sn 0.46.0

Locale::CLDR::Locales::So 0.46.0

Locale::CLDR::Locales::Sq 0.46.0

Locale::CLDR::Locales::Sr 0.46.0

Locale::CLDR::Locales::Ss 0.46.0

Locale::CLDR::Locales::St 0.46.0

Locale::CLDR::Locales::Su 0.46.0

Locale::CLDR::Locales::Sv 0.46.0

Locale::CLDR::Locales::Sw 0.46.0

Locale::CLDR::Locales::Ta 0.46.0

Locale::CLDR::Locales::Te 0.46.0

Locale::CLDR::Locales::Tg 0.46.0

Locale::CLDR::Locales::Th 0.46.0

Locale::CLDR::Locales::Ti 0.46.0

Locale::CLDR::Locales::Tk 0.46.0

Locale::CLDR::Locales::Tn 0.46.0

Locale::CLDR::Locales::To 0.46.0

Locale::CLDR::Locales::Tr 0.46.0

Locale::CLDR::Locales::Ts 0.46.0

Locale::CLDR::Locales::Tt 0.46.0

Locale::CLDR::Locales::Ug 0.46.0

Locale::CLDR::Locales::Uk 0.46.0

Locale::CLDR::Locales::Ur 0.46.0

Locale::CLDR::Locales::Uz 0.46.0

Locale::CLDR::Locales::Ve 0.46.0

Locale::CLDR::Locales::Vi 0.46.0

Locale::CLDR::Locales::Wa 0.46.0

Locale::CLDR::Locales::Wo 0.46.0

Locale::CLDR::Locales::Xh 0.46.0

Locale::CLDR::Locales::Yi 0.46.0

Locale::CLDR::Locales::Yo 0.46.0

Locale::CLDR::Locales::Za 0.46.0

Locale::CLDR::Locales::Zh 0.46.0

Locale::CLDR::Locales::Zu 0.46.0

Locale::CLDR::Locales::Agq 0.46.0

Locale::CLDR::Locales::Ann 0.46.0

Locale::CLDR::Locales::Apc 0.46.0

Locale::CLDR::Locales::Arn 0.46.0

Locale::CLDR::Locales::Asa 0.46.0

Locale::CLDR::Locales::Ast 0.46.0

Locale::CLDR::Locales::Bal 0.46.0

Locale::CLDR::Locales::Bas 0.46.0

Locale::CLDR::Locales::Bem 0.46.0

Locale::CLDR::Locales::Bew 0.46.0

Locale::CLDR::Locales::Bez 0.46.0

Locale::CLDR::Locales::Bgc 0.46.0

Locale::CLDR::Locales::Bgn 0.46.0

Locale::CLDR::Locales::Bho 0.46.0

Locale::CLDR::Locales::Blo 0.46.0

Locale::CLDR::Locales::Blt 0.46.0

Locale::CLDR::Locales::Brx 0.46.0

Locale::CLDR::Locales::Bss 0.46.0

Locale::CLDR::Locales::Byn 0.46.0

Locale::CLDR::Locales::Cad 0.46.0

Locale::CLDR::Locales::Cch 0.46.0

Locale::CLDR::Locales::Ccp 0.46.0

Locale::CLDR::Locales::Ceb 0.46.0

Locale::CLDR::Locales::Cgg 0.46.0

Locale::CLDR::Locales::Cho 0.46.0

Locale::CLDR::Locales::Chr 0.46.0

Locale::CLDR::Locales::Cic 0.46.0

Locale::CLDR::Locales::Ckb 0.46.0

Locale::CLDR::Locales::Csw 0.46.0

Locale::CLDR::Locales::Dav 0.46.0

Locale::CLDR::Locales::Dje 0.46.0

Locale::CLDR::Locales::Doi 0.46.0

Locale::CLDR::Locales::Dsb 0.46.0

Locale::CLDR::Locales::Dua 0.46.0

Locale::CLDR::Locales::Dyo 0.46.0

Locale::CLDR::Locales::Ebu 0.46.0

Locale::CLDR::Locales::Ewo 0.46.0

Locale::CLDR::Locales::Fil 0.46.0

Locale::CLDR::Locales::Frr 0.46.0

Locale::CLDR::Locales::Fur 0.46.0

Locale::CLDR::Locales::Gaa 0.46.0

Locale::CLDR::Locales::Gez 0.46.0

Locale::CLDR::Locales::Gsw 0.46.0

Locale::CLDR::Locales::Guz 0.46.0

Locale::CLDR::Locales::Haw 0.46.0

Locale::CLDR::Locales::Hnj 0.46.0

Locale::CLDR::Locales::Hsb 0.46.0

Locale::CLDR::Locales::Jgo 0.46.0

Locale::CLDR::Locales::Jmc 0.46.0

Locale::CLDR::Locales::Kaa 0.46.0

Locale::CLDR::Locales::Kab 0.46.0

Locale::CLDR::Locales::Kaj 0.46.0

Locale::CLDR::Locales::Kam 0.46.0

Locale::CLDR::Locales::Kcg 0.46.0

Locale::CLDR::Locales::Kde 0.46.0

Locale::CLDR::Locales::Kea 0.46.0

Locale::CLDR::Locales::Ken 0.46.0

Locale::CLDR::Locales::Kgp 0.46.0

Locale::CLDR::Locales::Khq 0.46.0

Locale::CLDR::Locales::Kkj 0.46.0

Locale::CLDR::Locales::Kln 0.46.0

Locale::CLDR::Locales::Kok 0.46.0

Locale::CLDR::Locales::Kpe 0.46.0

Locale::CLDR::Locales::Ksb 0.46.0

Locale::CLDR::Locales::Ksf 0.46.0

Locale::CLDR::Locales::Ksh 0.46.0

Locale::CLDR::Locales::Kxv 0.46.0

Locale::CLDR::Locales::Lag 0.46.0

Locale::CLDR::Locales::Lij 0.46.0

Locale::CLDR::Locales::Lkt 0.46.0

Locale::CLDR::Locales::Lld 0.46.0

Locale::CLDR::Locales::Lmo 0.46.0

Locale::CLDR::Locales::Lrc 0.46.0

Locale::CLDR::Locales::Ltg 0.46.0

Locale::CLDR::Locales::Luo 0.46.0

Locale::CLDR::Locales::Luy 0.46.0

Locale::CLDR::Locales::Mai 0.46.0

Locale::CLDR::Locales::Mas 0.46.0

Locale::CLDR::Locales::Mdf 0.46.0

Locale::CLDR::Locales::Mer 0.46.0

Locale::CLDR::Locales::Mfe 0.46.0

Locale::CLDR::Locales::Mgh 0.46.0

Locale::CLDR::Locales::Mgo 0.46.0

Locale::CLDR::Locales::Mhn 0.46.0

Locale::CLDR::Locales::Mic 0.46.0

Locale::CLDR::Locales::Mni 0.46.0

Locale::CLDR::Locales::Moh 0.46.0

Locale::CLDR::Locales::Mua 0.46.0

Locale::CLDR::Locales::Mus 0.46.0

Locale::CLDR::Locales::Myv 0.46.0

Locale::CLDR::Locales::Mzn 0.46.0

Locale::CLDR::Locales::Naq 0.46.0

Locale::CLDR::Locales::Nds 0.46.0

Locale::CLDR::Locales::Nmg 0.46.0

Locale::CLDR::Locales::Nnh 0.46.0

Locale::CLDR::Locales::Nqo 0.46.0

Locale::CLDR::Locales::Nso 0.46.0

Locale::CLDR::Locales::Nus 0.46.0

Locale::CLDR::Locales::Nyn 0.46.0

Locale::CLDR::Locales::Osa 0.46.0

Locale::CLDR::Locales::Pcm 0.46.0

Locale::CLDR::Locales::Pis 0.46.0

Locale::CLDR::Locales::Prg 0.46.0

Locale::CLDR::Locales::Quc 0.46.0

Locale::CLDR::Locales::Raj 0.46.0

Locale::CLDR::Locales::Rhg 0.46.0

Locale::CLDR::Locales::Rif 0.46.0

Locale::CLDR::Locales::Rof 0.46.0

Locale::CLDR::Locales::Rwk 0.46.0

Locale::CLDR::Locales::Sah 0.46.0

Locale::CLDR::Locales::Saq 0.46.0

Locale::CLDR::Locales::Sat 0.46.0

Locale::CLDR::Locales::Sbp 0.46.0

Locale::CLDR::Locales::Scn 0.46.0

Locale::CLDR::Locales::Sdh 0.46.0

Locale::CLDR::Locales::Seh 0.46.0

Locale::CLDR::Locales::Ses 0.46.0

Locale::CLDR::Locales::Shi 0.46.0

Locale::CLDR::Locales::Shn 0.46.0

Locale::CLDR::Locales::Sid 0.46.0

Locale::CLDR::Locales::Skr 0.46.0

Locale::CLDR::Locales::Sma 0.46.0

Locale::CLDR::Locales::Smj 0.46.0

Locale::CLDR::Locales::Smn 0.46.0

Locale::CLDR::Locales::Sms 0.46.0

Locale::CLDR::Locales::Ssy 0.46.0

Locale::CLDR::Locales::Syr 0.46.0

Locale::CLDR::Locales::Szl 0.46.0

Locale::CLDR::Locales::Teo 0.46.0

Locale::CLDR::Locales::Tig 0.46.0

Locale::CLDR::Locales::Tpi 0.46.0

Locale::CLDR::Locales::Trw 0.46.0

Locale::CLDR::Locales::Twq 0.46.0

Locale::CLDR::Locales::Tyv 0.46.0

Locale::CLDR::Locales::Tzm 0.46.0

Locale::CLDR::Locales::Vai 0.46.0

Locale::CLDR::Locales::Vec 0.46.0

Locale::CLDR::Locales::Vmw 0.46.0

Locale::CLDR::Locales::Vun 0.46.0

Locale::CLDR::Locales::Wae 0.46.0

Locale::CLDR::Locales::Wal 0.46.0

Locale::CLDR::Locales::Wbp 0.46.0

Locale::CLDR::Locales::Xnr 0.46.0

Locale::CLDR::Locales::Xog 0.46.0

Locale::CLDR::Locales::Yav 0.46.0

Locale::CLDR::Locales::Yrl 0.46.0

Locale::CLDR::Locales::Yue 0.46.0

Locale::CLDR::Locales::Zgh 0.46.0

Locale::CLDR::Locales::Aa::Latn 0.46.0

Locale::CLDR::Locales::Ab::Cyrl 0.46.0

Locale::CLDR::Locales::Af::Latn 0.46.0

Locale::CLDR::Locales::Ak::Latn 0.46.0

Locale::CLDR::Locales::Am::Ethi 0.46.0

Locale::CLDR::Locales::An::Latn 0.46.0

Locale::CLDR::Locales::Ar::Arab 0.46.0

Locale::CLDR::Locales::As::Beng 0.46.0

Locale::CLDR::Locales::Az::Arab 0.46.0

Locale::CLDR::Locales::Az::Cyrl 0.46.0

Locale::CLDR::Locales::Az::Latn 0.46.0

Locale::CLDR::Locales::Ba::Cyrl 0.46.0

Locale::CLDR::Locales::Be::Cyrl 0.46.0

Locale::CLDR::Locales::Bg::Cyrl 0.46.0

Locale::CLDR::Locales::Bm::Latn 0.46.0

Locale::CLDR::Locales::Bm::Nkoo 0.46.0

Locale::CLDR::Locales::Bn::Beng 0.46.0

Locale::CLDR::Locales::Bo::Tibt 0.46.0

Locale::CLDR::Locales::Br::Latn 0.46.0

Locale::CLDR::Locales::Bs::Cyrl 0.46.0

Locale::CLDR::Locales::Bs::Latn 0.46.0

Locale::CLDR::Locales::Ca::Latn 0.46.0

Locale::CLDR::Locales::Ce::Cyrl 0.46.0

Locale::CLDR::Locales::Co::Latn 0.46.0

Locale::CLDR::Locales::Cs::Latn 0.46.0

Locale::CLDR::Locales::Cu::Cyrl 0.46.0

Locale::CLDR::Locales::Cv::Cyrl 0.46.0

Locale::CLDR::Locales::Cy::Latn 0.46.0

Locale::CLDR::Locales::Da::Latn 0.46.0

Locale::CLDR::Locales::De::Latn 0.46.0

Locale::CLDR::Locales::Dv::Thaa 0.46.0

Locale::CLDR::Locales::Dz::Tibt 0.46.0

Locale::CLDR::Locales::Ee::Latn 0.46.0

Locale::CLDR::Locales::El::Grek 0.46.0

Locale::CLDR::Locales::En::Dsrt 0.46.0

Locale::CLDR::Locales::En::Shaw 0.46.0

Locale::CLDR::Locales::Es::Latn 0.46.0

Locale::CLDR::Locales::Et::Latn 0.46.0

Locale::CLDR::Locales::Eu::Latn 0.46.0

Locale::CLDR::Locales::Fa::Arab 0.46.0

Locale::CLDR::Locales::Ff::Adlm 0.46.0

Locale::CLDR::Locales::Ff::Latn 0.46.0

Locale::CLDR::Locales::Fi::Latn 0.46.0

Locale::CLDR::Locales::Fo::Latn 0.46.0

Locale::CLDR::Locales::Fr::Latn 0.46.0

Locale::CLDR::Locales::Fy::Latn 0.46.0

Locale::CLDR::Locales::Ga::Latn 0.46.0

Locale::CLDR::Locales::Gd::Latn 0.46.0

Locale::CLDR::Locales::Gl::Latn 0.46.0

Locale::CLDR::Locales::Gn::Latn 0.46.0

Locale::CLDR::Locales::Gu::Gujr 0.46.0

Locale::CLDR::Locales::Ha::Arab 0.46.0

Locale::CLDR::Locales::Ha::Latn 0.46.0

Locale::CLDR::Locales::He::Hebr 0.46.0

Locale::CLDR::Locales::Hi::Deva 0.46.0

Locale::CLDR::Locales::Hi::Latn 0.46.0

Locale::CLDR::Locales::Hr::Latn 0.46.0

Locale::CLDR::Locales::Hu::Latn 0.46.0

Locale::CLDR::Locales::Hy::Armn 0.46.0

Locale::CLDR::Locales::Id::Latn 0.46.0

Locale::CLDR::Locales::Ie::Latn 0.46.0

Locale::CLDR::Locales::Ig::Latn 0.46.0

Locale::CLDR::Locales::Ii::Yiii 0.46.0

Locale::CLDR::Locales::Is::Latn 0.46.0

Locale::CLDR::Locales::It::Latn 0.46.0

Locale::CLDR::Locales::Iu::Cans 0.46.0

Locale::CLDR::Locales::Iu::Latn 0.46.0

Locale::CLDR::Locales::Ja::Jpan 0.46.0

Locale::CLDR::Locales::Jv::Latn 0.46.0

Locale::CLDR::Locales::Ka::Geor 0.46.0

Locale::CLDR::Locales::Ki::Latn 0.46.0

Locale::CLDR::Locales::Kk::Arab 0.46.0

Locale::CLDR::Locales::Kk::Cyrl 0.46.0

Locale::CLDR::Locales::Km::Khmr 0.46.0

Locale::CLDR::Locales::Kn::Knda 0.46.0

Locale::CLDR::Locales::Ko::Kore 0.46.0

Locale::CLDR::Locales::Ks::Arab 0.46.0

Locale::CLDR::Locales::Ks::Deva 0.46.0

Locale::CLDR::Locales::Ku::Latn 0.46.0

Locale::CLDR::Locales::Kw::Latn 0.46.0

Locale::CLDR::Locales::Ky::Cyrl 0.46.0

Locale::CLDR::Locales::Lb::Latn 0.46.0

Locale::CLDR::Locales::Lg::Latn 0.46.0

Locale::CLDR::Locales::Ln::Latn 0.46.0

Locale::CLDR::Locales::Lo::Laoo 0.46.0

Locale::CLDR::Locales::Lt::Latn 0.46.0

Locale::CLDR::Locales::Lu::Latn 0.46.0

Locale::CLDR::Locales::Lv::Latn 0.46.0

Locale::CLDR::Locales::Mg::Latn 0.46.0

Locale::CLDR::Locales::Mi::Latn 0.46.0

Locale::CLDR::Locales::Mk::Cyrl 0.46.0

Locale::CLDR::Locales::Ml::Mlym 0.46.0

Locale::CLDR::Locales::Mn::Cyrl 0.46.0

Locale::CLDR::Locales::Mn::Mong 0.46.0

Locale::CLDR::Locales::Mr::Deva 0.46.0

Locale::CLDR::Locales::Ms::Arab 0.46.0

Locale::CLDR::Locales::Ms::Latn 0.46.0

Locale::CLDR::Locales::Mt::Latn 0.46.0

Locale::CLDR::Locales::My::Mymr 0.46.0

Locale::CLDR::Locales::Nb::Latn 0.46.0

Locale::CLDR::Locales::Nd::Latn 0.46.0

Locale::CLDR::Locales::Ne::Deva 0.46.0

Locale::CLDR::Locales::Nl::Latn 0.46.0

Locale::CLDR::Locales::Nn::Latn 0.46.0

Locale::CLDR::Locales::Nr::Latn 0.46.0

Locale::CLDR::Locales::Nv::Latn 0.46.0

Locale::CLDR::Locales::Ny::Latn 0.46.0

Locale::CLDR::Locales::Oc::Latn 0.46.0

Locale::CLDR::Locales::Om::Latn 0.46.0

Locale::CLDR::Locales::Or::Orya 0.46.0

Locale::CLDR::Locales::Os::Cyrl 0.46.0

Locale::CLDR::Locales::Pa::Arab 0.46.0

Locale::CLDR::Locales::Pa::Guru 0.46.0

Locale::CLDR::Locales::Pl::Latn 0.46.0

Locale::CLDR::Locales::Ps::Arab 0.46.0

Locale::CLDR::Locales::Pt::Latn 0.46.0

Locale::CLDR::Locales::Qu::Latn 0.46.0

Locale::CLDR::Locales::Rm::Latn 0.46.0

Locale::CLDR::Locales::Rn::Latn 0.46.0

Locale::CLDR::Locales::Ro::Latn 0.46.0

Locale::CLDR::Locales::Ru::Cyrl 0.46.0

Locale::CLDR::Locales::Rw::Latn 0.46.0

Locale::CLDR::Locales::Sa::Deva 0.46.0

Locale::CLDR::Locales::Sc::Latn 0.46.0

Locale::CLDR::Locales::Sd::Arab 0.46.0

Locale::CLDR::Locales::Sd::Deva 0.46.0

Locale::CLDR::Locales::Se::Latn 0.46.0

Locale::CLDR::Locales::Sg::Latn 0.46.0

Locale::CLDR::Locales::Si::Sinh 0.46.0

Locale::CLDR::Locales::Sk::Latn 0.46.0

Locale::CLDR::Locales::Sl::Latn 0.46.0

Locale::CLDR::Locales::Sn::Latn 0.46.0

Locale::CLDR::Locales::So::Latn 0.46.0

Locale::CLDR::Locales::Sq::Latn 0.46.0

Locale::CLDR::Locales::Sr::Cyrl 0.46.0

Locale::CLDR::Locales::Sr::Latn 0.46.0

Locale::CLDR::Locales::Ss::Latn 0.46.0

Locale::CLDR::Locales::St::Latn 0.46.0

Locale::CLDR::Locales::Su::Latn 0.46.0

Locale::CLDR::Locales::Sv::Latn 0.46.0

Locale::CLDR::Locales::Sw::Latn 0.46.0

Locale::CLDR::Locales::Ta::Taml 0.46.0

Locale::CLDR::Locales::Te::Telu 0.46.0

Locale::CLDR::Locales::Tg::Cyrl 0.46.0

Locale::CLDR::Locales::Th::Thai 0.46.0

Locale::CLDR::Locales::Ti::Ethi 0.46.0

Locale::CLDR::Locales::Tk::Latn 0.46.0

Locale::CLDR::Locales::Tn::Latn 0.46.0

Locale::CLDR::Locales::To::Latn 0.46.0

Locale::CLDR::Locales::Tr::Latn 0.46.0

Locale::CLDR::Locales::Ts::Latn 0.46.0

Locale::CLDR::Locales::Tt::Cyrl 0.46.0

Locale::CLDR::Locales::Ug::Arab 0.46.0

Locale::CLDR::Locales::Uk::Cyrl 0.46.0

Locale::CLDR::Locales::Ur::Arab 0.46.0

Locale::CLDR::Locales::Uz::Arab 0.46.0

Locale::CLDR::Locales::Uz::Cyrl 0.46.0

Locale::CLDR::Locales::Uz::Latn 0.46.0

Locale::CLDR::Locales::Ve::Latn 0.46.0

Locale::CLDR::Locales::Vi::Latn 0.46.0

Locale::CLDR::Locales::Wa::Latn 0.46.0

Locale::CLDR::Locales::Wo::Latn 0.46.0

Locale::CLDR::Locales::Xh::Latn 0.46.0

Locale::CLDR::Locales::Yi::Hebr 0.46.0

Locale::CLDR::Locales::Yo::Latn 0.46.0

Locale::CLDR::Locales::Za::Latn 0.46.0

Locale::CLDR::Locales::Zh::Hans 0.46.0

Locale::CLDR::Locales::Zh::Hant 0.46.0

Locale::CLDR::Locales::Zh::Latn 0.46.0

Locale::CLDR::Locales::Zu::Latn 0.46.0

Locale::CLDR::Locales::Agq::Latn 0.46.0

Locale::CLDR::Locales::Ann::Latn 0.46.0

Locale::CLDR::Locales::Apc::Arab 0.46.0

Locale::CLDR::Locales::Arn::Latn 0.46.0

Locale::CLDR::Locales::Asa::Latn 0.46.0

Locale::CLDR::Locales::Ast::Latn 0.46.0

Locale::CLDR::Locales::Bal::Arab 0.46.0

Locale::CLDR::Locales::Bal::Latn 0.46.0

Locale::CLDR::Locales::Bas::Latn 0.46.0

Locale::CLDR::Locales::Bem::Latn 0.46.0

Locale::CLDR::Locales::Bew::Latn 0.46.0

Locale::CLDR::Locales::Bez::Latn 0.46.0

Locale::CLDR::Locales::Bgc::Deva 0.46.0

Locale::CLDR::Locales::Bgn::Arab 0.46.0

Locale::CLDR::Locales::Bho::Deva 0.46.0

Locale::CLDR::Locales::Blo::Latn 0.46.0

Locale::CLDR::Locales::Blt::Tavt 0.46.0

Locale::CLDR::Locales::Brx::Deva 0.46.0

Locale::CLDR::Locales::Bss::Latn 0.46.0

Locale::CLDR::Locales::Byn::Ethi 0.46.0

Locale::CLDR::Locales::Cad::Latn 0.46.0

Locale::CLDR::Locales::Cch::Latn 0.46.0

Locale::CLDR::Locales::Ccp::Cakm 0.46.0

Locale::CLDR::Locales::Ceb::Latn 0.46.0

Locale::CLDR::Locales::Cgg::Latn 0.46.0

Locale::CLDR::Locales::Cho::Latn 0.46.0

Locale::CLDR::Locales::Chr::Cher 0.46.0

Locale::CLDR::Locales::Cic::Latn 0.46.0

Locale::CLDR::Locales::Ckb::Arab 0.46.0

Locale::CLDR::Locales::Csw::Cans 0.46.0

Locale::CLDR::Locales::Dav::Latn 0.46.0

Locale::CLDR::Locales::Dje::Latn 0.46.0

Locale::CLDR::Locales::Doi::Deva 0.46.0

Locale::CLDR::Locales::Dsb::Latn 0.46.0

Locale::CLDR::Locales::Dua::Latn 0.46.0

Locale::CLDR::Locales::Dyo::Latn 0.46.0

Locale::CLDR::Locales::Ebu::Latn 0.46.0

Locale::CLDR::Locales::Ewo::Latn 0.46.0

Locale::CLDR::Locales::Fil::Latn 0.46.0

Locale::CLDR::Locales::Frr::Latn 0.46.0

Locale::CLDR::Locales::Fur::Latn 0.46.0

Locale::CLDR::Locales::Gaa::Latn 0.46.0

Locale::CLDR::Locales::Gez::Ethi 0.46.0

Locale::CLDR::Locales::Gsw::Latn 0.46.0

Locale::CLDR::Locales::Guz::Latn 0.46.0

Locale::CLDR::Locales::Haw::Latn 0.46.0

Locale::CLDR::Locales::Hnj::Hmnp 0.46.0

Locale::CLDR::Locales::Hsb::Latn 0.46.0

Locale::CLDR::Locales::Jgo::Latn 0.46.0

Locale::CLDR::Locales::Jmc::Latn 0.46.0

Locale::CLDR::Locales::Kaa::Cyrl 0.46.0

Locale::CLDR::Locales::Kaa::Latn 0.46.0

Locale::CLDR::Locales::Kab::Latn 0.46.0

Locale::CLDR::Locales::Kaj::Latn 0.46.0

Locale::CLDR::Locales::Kam::Latn 0.46.0

Locale::CLDR::Locales::Kcg::Latn 0.46.0

Locale::CLDR::Locales::Kde::Latn 0.46.0

Locale::CLDR::Locales::Kea::Latn 0.46.0

Locale::CLDR::Locales::Ken::Latn 0.46.0

Locale::CLDR::Locales::Kgp::Latn 0.46.0

Locale::CLDR::Locales::Khq::Latn 0.46.0

Locale::CLDR::Locales::Kkj::Latn 0.46.0

Locale::CLDR::Locales::Kln::Latn 0.46.0

Locale::CLDR::Locales::Kok::Deva 0.46.0

Locale::CLDR::Locales::Kok::Latn 0.46.0

Locale::CLDR::Locales::Kpe::Latn 0.46.0

Locale::CLDR::Locales::Ksb::Latn 0.46.0

Locale::CLDR::Locales::Ksf::Latn 0.46.0

Locale::CLDR::Locales::Ksh::Latn 0.46.0

Locale::CLDR::Locales::Kxv::Deva 0.46.0

Locale::CLDR::Locales::Kxv::Latn 0.46.0

Locale::CLDR::Locales::Kxv::Orya 0.46.0

Locale::CLDR::Locales::Kxv::Telu 0.46.0

Locale::CLDR::Locales::Lag::Latn 0.46.0

Locale::CLDR::Locales::Lij::Latn 0.46.0

Locale::CLDR::Locales::Lkt::Latn 0.46.0

Locale::CLDR::Locales::Lld::Latn 0.46.0

Locale::CLDR::Locales::Lmo::Latn 0.46.0

Locale::CLDR::Locales::Lrc::Arab 0.46.0

Locale::CLDR::Locales::Ltg::Latn 0.46.0

Locale::CLDR::Locales::Luo::Latn 0.46.0

Locale::CLDR::Locales::Luy::Latn 0.46.0

Locale::CLDR::Locales::Mai::Deva 0.46.0

Locale::CLDR::Locales::Mas::Latn 0.46.0

Locale::CLDR::Locales::Mdf::Cyrl 0.46.0

Locale::CLDR::Locales::Mer::Latn 0.46.0

Locale::CLDR::Locales::Mfe::Latn 0.46.0

Locale::CLDR::Locales::Mgh::Latn 0.46.0

Locale::CLDR::Locales::Mgo::Latn 0.46.0

Locale::CLDR::Locales::Mhn::Latn 0.46.0

Locale::CLDR::Locales::Mic::Latn 0.46.0

Locale::CLDR::Locales::Mni::Beng 0.46.0

Locale::CLDR::Locales::Mni::Mtei 0.46.0

Locale::CLDR::Locales::Moh::Latn 0.46.0

Locale::CLDR::Locales::Mua::Latn 0.46.0

Locale::CLDR::Locales::Mus::Latn 0.46.0

Locale::CLDR::Locales::Myv::Cyrl 0.46.0

Locale::CLDR::Locales::Mzn::Arab 0.46.0

Locale::CLDR::Locales::Naq::Latn 0.46.0

Locale::CLDR::Locales::Nds::Latn 0.46.0

Locale::CLDR::Locales::Nmg::Latn 0.46.0

Locale::CLDR::Locales::Nnh::Latn 0.46.0

Locale::CLDR::Locales::Nqo::Nkoo 0.46.0

Locale::CLDR::Locales::Nso::Latn 0.46.0

Locale::CLDR::Locales::Nus::Latn 0.46.0

Locale::CLDR::Locales::Nyn::Latn 0.46.0

Locale::CLDR::Locales::Osa::Osge 0.46.0

Locale::CLDR::Locales::Pcm::Latn 0.46.0

Locale::CLDR::Locales::Pis::Latn 0.46.0

Locale::CLDR::Locales::Prg::Latn 0.46.0

Locale::CLDR::Locales::Quc::Latn 0.46.0

Locale::CLDR::Locales::Raj::Deva 0.46.0

Locale::CLDR::Locales::Rhg::Rohg 0.46.0

Locale::CLDR::Locales::Rif::Latn 0.46.0

Locale::CLDR::Locales::Rof::Latn 0.46.0

Locale::CLDR::Locales::Rwk::Latn 0.46.0

Locale::CLDR::Locales::Sah::Cyrl 0.46.0

Locale::CLDR::Locales::Saq::Latn 0.46.0

Locale::CLDR::Locales::Sat::Deva 0.46.0

Locale::CLDR::Locales::Sat::Olck 0.46.0

Locale::CLDR::Locales::Sbp::Latn 0.46.0

Locale::CLDR::Locales::Scn::Latn 0.46.0

Locale::CLDR::Locales::Sdh::Arab 0.46.0

Locale::CLDR::Locales::Seh::Latn 0.46.0

Locale::CLDR::Locales::Ses::Latn 0.46.0

Locale::CLDR::Locales::Shi::Latn 0.46.0

Locale::CLDR::Locales::Shi::Tfng 0.46.0

Locale::CLDR::Locales::Shn::Mymr 0.46.0

Locale::CLDR::Locales::Sid::Latn 0.46.0

Locale::CLDR::Locales::Skr::Arab 0.46.0

Locale::CLDR::Locales::Sma::Latn 0.46.0

Locale::CLDR::Locales::Smj::Latn 0.46.0

Locale::CLDR::Locales::Smn::Latn 0.46.0

Locale::CLDR::Locales::Sms::Latn 0.46.0

Locale::CLDR::Locales::Ssy::Latn 0.46.0

Locale::CLDR::Locales::Syr::Syrc 0.46.0

Locale::CLDR::Locales::Szl::Latn 0.46.0

Locale::CLDR::Locales::Teo::Latn 0.46.0

Locale::CLDR::Locales::Tig::Ethi 0.46.0

Locale::CLDR::Locales::Tpi::Latn 0.46.0

Locale::CLDR::Locales::Trw::Arab 0.46.0

Locale::CLDR::Locales::Twq::Latn 0.46.0

Locale::CLDR::Locales::Tyv::Cyrl 0.46.0

Locale::CLDR::Locales::Tzm::Latn 0.46.0

Locale::CLDR::Locales::Vai::Latn 0.46.0

Locale::CLDR::Locales::Vai::Vaii 0.46.0

Locale::CLDR::Locales::Vec::Latn 0.46.0

Locale::CLDR::Locales::Vmw::Latn 0.46.0

Locale::CLDR::Locales::Vun::Latn 0.46.0

Locale::CLDR::Locales::Wae::Latn 0.46.0

Locale::CLDR::Locales::Wal::Ethi 0.46.0

Locale::CLDR::Locales::Wbp::Latn 0.46.0

Locale::CLDR::Locales::Xnr::Deva 0.46.0

Locale::CLDR::Locales::Xog::Latn 0.46.0

Locale::CLDR::Locales::Yav::Latn 0.46.0

Locale::CLDR::Locales::Yrl::Latn 0.46.0

Locale::CLDR::Locales::Yue::Hans 0.46.0

Locale::CLDR::Locales::Yue::Hant 0.46.0

Locale::CLDR::Locales::Zgh::Tfng 0.46.0

Locale::CLDR::Locales::Aa::Latn::Dj 0.46.0

Locale::CLDR::Locales::Aa::Latn::Er 0.46.0

Locale::CLDR::Locales::Aa::Latn::Et 0.46.0

Locale::CLDR::Locales::Ab::Cyrl::Ge 0.46.0

Locale::CLDR::Locales::Af::Latn::Na 0.46.0

Locale::CLDR::Locales::Af::Latn::Za 0.46.0

Locale::CLDR::Locales::Ak::Latn::Gh 0.46.0

Locale::CLDR::Locales::Am::Ethi::Et 0.46.0

Locale::CLDR::Locales::An::Latn::Es 0.46.0

Locale::CLDR::Locales::Ar::Arab::Ae 0.46.0

Locale::CLDR::Locales::Ar::Arab::Bh 0.46.0

Locale::CLDR::Locales::Ar::Arab::Dj 0.46.0

Locale::CLDR::Locales::Ar::Arab::Dz 0.46.0

Locale::CLDR::Locales::Ar::Arab::Eg 0.46.0

Locale::CLDR::Locales::Ar::Arab::Er 0.46.0

Locale::CLDR::Locales::Ar::Arab::Il 0.46.0

Locale::CLDR::Locales::Ar::Arab::Iq 0.46.0

Locale::CLDR::Locales::Ar::Arab::Jo 0.46.0

Locale::CLDR::Locales::Ar::Arab::Km 0.46.0

Locale::CLDR::Locales::Ar::Arab::Kw 0.46.0

Locale::CLDR::Locales::Ar::Arab::Lb 0.46.0

Locale::CLDR::Locales::Ar::Arab::Ly 0.46.0

Locale::CLDR::Locales::Ar::Arab::Ma 0.46.0

Locale::CLDR::Locales::Ar::Arab::Mr 0.46.0

Locale::CLDR::Locales::Ar::Arab::Om 0.46.0

Locale::CLDR::Locales::Ar::Arab::Qa 0.46.0

Locale::CLDR::Locales::Ar::Arab::Sa 0.46.0

Locale::CLDR::Locales::Ar::Arab::Sd 0.46.0

Locale::CLDR::Locales::Ar::Arab::So 0.46.0

Locale::CLDR::Locales::Ar::Arab::Ss 0.46.0

Locale::CLDR::Locales::Ar::Arab::Sy 0.46.0

Locale::CLDR::Locales::Ar::Arab::Td 0.46.0

Locale::CLDR::Locales::Ar::Arab::Tn 0.46.0

Locale::CLDR::Locales::Ar::Arab::Ye 0.46.0

Locale::CLDR::Locales::As::Beng::In 0.46.0

Locale::CLDR::Locales::Az::Arab::Iq 0.46.0

Locale::CLDR::Locales::Az::Arab::Ir 0.46.0

Locale::CLDR::Locales::Az::Arab::Tr 0.46.0

Locale::CLDR::Locales::Az::Cyrl::Az 0.46.0

Locale::CLDR::Locales::Az::Latn::Az 0.46.0

Locale::CLDR::Locales::Ba::Cyrl::Ru 0.46.0

Locale::CLDR::Locales::Be::Cyrl::By 0.46.0

Locale::CLDR::Locales::Bg::Cyrl::Bg 0.46.0

Locale::CLDR::Locales::Bm::Latn::Ml 0.46.0

Locale::CLDR::Locales::Bm::Nkoo::Ml 0.46.0

Locale::CLDR::Locales::Bn::Beng::Bd 0.46.0

Locale::CLDR::Locales::Bn::Beng::In 0.46.0

Locale::CLDR::Locales::Bo::Tibt::Cn 0.46.0

Locale::CLDR::Locales::Bo::Tibt::In 0.46.0

Locale::CLDR::Locales::Br::Latn::Fr 0.46.0

Locale::CLDR::Locales::Bs::Cyrl::Ba 0.46.0

Locale::CLDR::Locales::Bs::Latn::Ba 0.46.0

Locale::CLDR::Locales::Ca::Latn::Ad 0.46.0

Locale::CLDR::Locales::Ca::Latn::Es 0.46.0

Locale::CLDR::Locales::Ca::Latn::Fr 0.46.0

Locale::CLDR::Locales::Ca::Latn::It 0.46.0

Locale::CLDR::Locales::Ce::Cyrl::Ru 0.46.0

Locale::CLDR::Locales::Co::Latn::Fr 0.46.0

Locale::CLDR::Locales::Cs::Latn::Cz 0.46.0

Locale::CLDR::Locales::Cu::Cyrl::Ru 0.46.0

Locale::CLDR::Locales::Cv::Cyrl::Ru 0.46.0

Locale::CLDR::Locales::Cy::Latn::Gb 0.46.0

Locale::CLDR::Locales::Da::Latn::Dk 0.46.0

Locale::CLDR::Locales::De::Latn::At 0.46.0

Locale::CLDR::Locales::De::Latn::Be 0.46.0

Locale::CLDR::Locales::De::Latn::Ch 0.46.0

Locale::CLDR::Locales::De::Latn::De 0.46.0

Locale::CLDR::Locales::De::Latn::It 0.46.0

Locale::CLDR::Locales::De::Latn::Li 0.46.0

Locale::CLDR::Locales::De::Latn::Lu 0.46.0

Locale::CLDR::Locales::Dv::Thaa::Mv 0.46.0

Locale::CLDR::Locales::Dz::Tibt::Bt 0.46.0

Locale::CLDR::Locales::Ee::Latn::Gh 0.46.0

Locale::CLDR::Locales::Ee::Latn::Tg 0.46.0

Locale::CLDR::Locales::El::Grek::Cy 0.46.0

Locale::CLDR::Locales::El::Grek::Gr 0.46.0

Locale::CLDR::Locales::En::Dsrt::Us 0.46.0

Locale::CLDR::Locales::En::Latn::Ae 0.46.0

Locale::CLDR::Locales::En::Latn::Ag 0.46.0

Locale::CLDR::Locales::En::Latn::At 0.46.0

Locale::CLDR::Locales::En::Latn::Au 0.46.0

Locale::CLDR::Locales::En::Latn::Bb 0.46.0

Locale::CLDR::Locales::En::Latn::Be 0.46.0

Locale::CLDR::Locales::En::Latn::Bi 0.46.0

Locale::CLDR::Locales::En::Latn::Bs 0.46.0

Locale::CLDR::Locales::En::Latn::Bw 0.46.0

Locale::CLDR::Locales::En::Latn::Bz 0.46.0

Locale::CLDR::Locales::En::Latn::Ca 0.46.0

Locale::CLDR::Locales::En::Latn::Ch 0.46.0

Locale::CLDR::Locales::En::Latn::Cm 0.46.0

Locale::CLDR::Locales::En::Latn::Cy 0.46.0

Locale::CLDR::Locales::En::Latn::De 0.46.0

Locale::CLDR::Locales::En::Latn::Dk 0.46.0

Locale::CLDR::Locales::En::Latn::Dm 0.46.0

Locale::CLDR::Locales::En::Latn::Er 0.46.0

Locale::CLDR::Locales::En::Latn::Fi 0.46.0

Locale::CLDR::Locales::En::Latn::Fj 0.46.0

Locale::CLDR::Locales::En::Latn::Fm 0.46.0

Locale::CLDR::Locales::En::Latn::Gb 0.46.0

Locale::CLDR::Locales::En::Latn::Gd 0.46.0

Locale::CLDR::Locales::En::Latn::Gh 0.46.0

Locale::CLDR::Locales::En::Latn::Gm 0.46.0

Locale::CLDR::Locales::En::Latn::Gy 0.46.0

Locale::CLDR::Locales::En::Latn::Id 0.46.0

Locale::CLDR::Locales::En::Latn::Ie 0.46.0

Locale::CLDR::Locales::En::Latn::Il 0.46.0

Locale::CLDR::Locales::En::Latn::In 0.46.0

Locale::CLDR::Locales::En::Latn::Jm 0.46.0

Locale::CLDR::Locales::En::Latn::Ke 0.46.0

Locale::CLDR::Locales::En::Latn::Ki 0.46.0

Locale::CLDR::Locales::En::Latn::Kn 0.46.0

Locale::CLDR::Locales::En::Latn::Lc 0.46.0

Locale::CLDR::Locales::En::Latn::Lr 0.46.0

Locale::CLDR::Locales::En::Latn::Ls 0.46.0

Locale::CLDR::Locales::En::Latn::Mg 0.46.0

Locale::CLDR::Locales::En::Latn::Mh 0.46.0

Locale::CLDR::Locales::En::Latn::Mt 0.46.0

Locale::CLDR::Locales::En::Latn::Mu 0.46.0

Locale::CLDR::Locales::En::Latn::Mv 0.46.0

Locale::CLDR::Locales::En::Latn::Mw 0.46.0

Locale::CLDR::Locales::En::Latn::My 0.46.0

Locale::CLDR::Locales::En::Latn::Na 0.46.0

Locale::CLDR::Locales::En::Latn::Ng 0.46.0

Locale::CLDR::Locales::En::Latn::Nl 0.46.0

Locale::CLDR::Locales::En::Latn::Nr 0.46.0

Locale::CLDR::Locales::En::Latn::Nz 0.46.0

Locale::CLDR::Locales::En::Latn::Pg 0.46.0

Locale::CLDR::Locales::En::Latn::Ph 0.46.0

Locale::CLDR::Locales::En::Latn::Pk 0.46.0

Locale::CLDR::Locales::En::Latn::Pw 0.46.0

Locale::CLDR::Locales::En::Latn::Rw 0.46.0

Locale::CLDR::Locales::En::Latn::Sb 0.46.0

Locale::CLDR::Locales::En::Latn::Sc 0.46.0

Locale::CLDR::Locales::En::Latn::Sd 0.46.0

Locale::CLDR::Locales::En::Latn::Se 0.46.0

Locale::CLDR::Locales::En::Latn::Sg 0.46.0

Locale::CLDR::Locales::En::Latn::Si 0.46.0

Locale::CLDR::Locales::En::Latn::Sl 0.46.0

Locale::CLDR::Locales::En::Latn::Ss 0.46.0

Locale::CLDR::Locales::En::Latn::Sz 0.46.0

Locale::CLDR::Locales::En::Latn::To 0.46.0

Locale::CLDR::Locales::En::Latn::Tt 0.46.0

Locale::CLDR::Locales::En::Latn::Tv 0.46.0

Locale::CLDR::Locales::En::Latn::Tz 0.46.0

Locale::CLDR::Locales::En::Latn::Ug 0.46.0

Locale::CLDR::Locales::En::Latn::Vc 0.46.0

Locale::CLDR::Locales::En::Latn::Vu 0.46.0

Locale::CLDR::Locales::En::Latn::Ws 0.46.0

Locale::CLDR::Locales::En::Latn::Za 0.46.0

Locale::CLDR::Locales::En::Latn::Zm 0.46.0

Locale::CLDR::Locales::En::Latn::Zw 0.46.0

Locale::CLDR::Locales::En::Shaw::Gb 0.46.0

Locale::CLDR::Locales::Es::Latn::Ar 0.46.0

Locale::CLDR::Locales::Es::Latn::Bo 0.46.0

Locale::CLDR::Locales::Es::Latn::Br 0.46.0

Locale::CLDR::Locales::Es::Latn::Bz 0.46.0

Locale::CLDR::Locales::Es::Latn::Cl 0.46.0

Locale::CLDR::Locales::Es::Latn::Co 0.46.0

Locale::CLDR::Locales::Es::Latn::Cr 0.46.0

Locale::CLDR::Locales::Es::Latn::Cu 0.46.0

Locale::CLDR::Locales::Es::Latn::Do 0.46.0

Locale::CLDR::Locales::Es::Latn::Ec 0.46.0

Locale::CLDR::Locales::Es::Latn::Es 0.46.0

Locale::CLDR::Locales::Es::Latn::Gq 0.46.0

Locale::CLDR::Locales::Es::Latn::Gt 0.46.0

Locale::CLDR::Locales::Es::Latn::Hn 0.46.0

Locale::CLDR::Locales::Es::Latn::Mx 0.46.0

Locale::CLDR::Locales::Es::Latn::Ni 0.46.0

Locale::CLDR::Locales::Es::Latn::Pa 0.46.0

Locale::CLDR::Locales::Es::Latn::Pe 0.46.0

Locale::CLDR::Locales::Es::Latn::Ph 0.46.0

Locale::CLDR::Locales::Es::Latn::Py 0.46.0

Locale::CLDR::Locales::Es::Latn::Sv 0.46.0

Locale::CLDR::Locales::Es::Latn::Us 0.46.0

Locale::CLDR::Locales::Es::Latn::Uy 0.46.0

Locale::CLDR::Locales::Es::Latn::Ve 0.46.0

Locale::CLDR::Locales::Et::Latn::Ee 0.46.0

Locale::CLDR::Locales::Eu::Latn::Es 0.46.0

Locale::CLDR::Locales::Fa::Arab::Af 0.46.0

Locale::CLDR::Locales::Fa::Arab::Ir 0.46.0

Locale::CLDR::Locales::Ff::Adlm::Bf 0.46.0

Locale::CLDR::Locales::Ff::Adlm::Cm 0.46.0

Locale::CLDR::Locales::Ff::Adlm::Gh 0.46.0

Locale::CLDR::Locales::Ff::Adlm::Gm 0.46.0

Locale::CLDR::Locales::Ff::Adlm::Gn 0.46.0

Locale::CLDR::Locales::Ff::Adlm::Gw 0.46.0

Locale::CLDR::Locales::Ff::Adlm::Lr 0.46.0

Locale::CLDR::Locales::Ff::Adlm::Mr 0.46.0

Locale::CLDR::Locales::Ff::Adlm::Ne 0.46.0

Locale::CLDR::Locales::Ff::Adlm::Ng 0.46.0

Locale::CLDR::Locales::Ff::Adlm::Sl 0.46.0

Locale::CLDR::Locales::Ff::Adlm::Sn 0.46.0

Locale::CLDR::Locales::Ff::Latn::Bf 0.46.0

Locale::CLDR::Locales::Ff::Latn::Cm 0.46.0

Locale::CLDR::Locales::Ff::Latn::Gh 0.46.0

Locale::CLDR::Locales::Ff::Latn::Gm 0.46.0

Locale::CLDR::Locales::Ff::Latn::Gn 0.46.0

Locale::CLDR::Locales::Ff::Latn::Gw 0.46.0

Locale::CLDR::Locales::Ff::Latn::Lr 0.46.0

Locale::CLDR::Locales::Ff::Latn::Mr 0.46.0

Locale::CLDR::Locales::Ff::Latn::Ne 0.46.0

Locale::CLDR::Locales::Ff::Latn::Ng 0.46.0

Locale::CLDR::Locales::Ff::Latn::Sl 0.46.0

Locale::CLDR::Locales::Ff::Latn::Sn 0.46.0

Locale::CLDR::Locales::Fi::Latn::Fi 0.46.0

Locale::CLDR::Locales::Fo::Latn::Dk 0.46.0

Locale::CLDR::Locales::Fr::Latn::Be 0.46.0

Locale::CLDR::Locales::Fr::Latn::Bf 0.46.0

Locale::CLDR::Locales::Fr::Latn::Bi 0.46.0

Locale::CLDR::Locales::Fr::Latn::Bj 0.46.0

Locale::CLDR::Locales::Fr::Latn::Ca 0.46.0

Locale::CLDR::Locales::Fr::Latn::Cd 0.46.0

Locale::CLDR::Locales::Fr::Latn::Cf 0.46.0

Locale::CLDR::Locales::Fr::Latn::Cg 0.46.0

Locale::CLDR::Locales::Fr::Latn::Ch 0.46.0

Locale::CLDR::Locales::Fr::Latn::Ci 0.46.0

Locale::CLDR::Locales::Fr::Latn::Cm 0.46.0

Locale::CLDR::Locales::Fr::Latn::Dj 0.46.0

Locale::CLDR::Locales::Fr::Latn::Dz 0.46.0

Locale::CLDR::Locales::Fr::Latn::Fr 0.46.0

Locale::CLDR::Locales::Fr::Latn::Ga 0.46.0

Locale::CLDR::Locales::Fr::Latn::Gn 0.46.0

Locale::CLDR::Locales::Fr::Latn::Gq 0.46.0

Locale::CLDR::Locales::Fr::Latn::Ht 0.46.0

Locale::CLDR::Locales::Fr::Latn::Km 0.46.0

Locale::CLDR::Locales::Fr::Latn::Lu 0.46.0

Locale::CLDR::Locales::Fr::Latn::Ma 0.46.0

Locale::CLDR::Locales::Fr::Latn::Mc 0.46.0

Locale::CLDR::Locales::Fr::Latn::Mg 0.46.0

Locale::CLDR::Locales::Fr::Latn::Ml 0.46.0

Locale::CLDR::Locales::Fr::Latn::Mr 0.46.0

Locale::CLDR::Locales::Fr::Latn::Mu 0.46.0

Locale::CLDR::Locales::Fr::Latn::Ne 0.46.0

Locale::CLDR::Locales::Fr::Latn::Rw 0.46.0

Locale::CLDR::Locales::Fr::Latn::Sc 0.46.0

Locale::CLDR::Locales::Fr::Latn::Sn 0.46.0

Locale::CLDR::Locales::Fr::Latn::Sy 0.46.0

Locale::CLDR::Locales::Fr::Latn::Td 0.46.0

Locale::CLDR::Locales::Fr::Latn::Tg 0.46.0

Locale::CLDR::Locales::Fr::Latn::Tn 0.46.0

Locale::CLDR::Locales::Fr::Latn::Vu 0.46.0

Locale::CLDR::Locales::Fy::Latn::Nl 0.46.0

Locale::CLDR::Locales::Ga::Latn::Gb 0.46.0

Locale::CLDR::Locales::Ga::Latn::Ie 0.46.0

Locale::CLDR::Locales::Gd::Latn::Gb 0.46.0

Locale::CLDR::Locales::Gl::Latn::Es 0.46.0

Locale::CLDR::Locales::Gn::Latn::Py 0.46.0

Locale::CLDR::Locales::Gu::Gujr::In 0.46.0

Locale::CLDR::Locales::Ha::Arab::Ng 0.46.0

Locale::CLDR::Locales::Ha::Arab::Sd 0.46.0

Locale::CLDR::Locales::Ha::Latn::Gh 0.46.0

Locale::CLDR::Locales::Ha::Latn::Ne 0.46.0

Locale::CLDR::Locales::Ha::Latn::Ng 0.46.0

Locale::CLDR::Locales::He::Hebr::Il 0.46.0

Locale::CLDR::Locales::Hi::Deva::In 0.46.0

Locale::CLDR::Locales::Hi::Latn::In 0.46.0

Locale::CLDR::Locales::Hr::Latn::Ba 0.46.0

Locale::CLDR::Locales::Hr::Latn::Hr 0.46.0

Locale::CLDR::Locales::Hu::Latn::Hu 0.46.0

Locale::CLDR::Locales::Hy::Armn::Am 0.46.0

Locale::CLDR::Locales::Id::Latn::Id 0.46.0

Locale::CLDR::Locales::Ie::Latn::Ee 0.46.0

Locale::CLDR::Locales::Ig::Latn::Ng 0.46.0

Locale::CLDR::Locales::Ii::Yiii::Cn 0.46.0

Locale::CLDR::Locales::Is::Latn::Is 0.46.0

Locale::CLDR::Locales::It::Latn::Ch 0.46.0

Locale::CLDR::Locales::It::Latn::It 0.46.0

Locale::CLDR::Locales::It::Latn::Sm 0.46.0

Locale::CLDR::Locales::Iu::Cans::Ca 0.46.0

Locale::CLDR::Locales::Iu::Latn::Ca 0.46.0

Locale::CLDR::Locales::Ja::Jpan::Jp 0.46.0

Locale::CLDR::Locales::Jv::Latn::Id 0.46.0

Locale::CLDR::Locales::Ka::Geor::Ge 0.46.0

Locale::CLDR::Locales::Ki::Latn::Ke 0.46.0

Locale::CLDR::Locales::Kk::Arab::Cn 0.46.0

Locale::CLDR::Locales::Kk::Cyrl::Kz 0.46.0

Locale::CLDR::Locales::Km::Khmr::Kh 0.46.0

Locale::CLDR::Locales::Kn::Knda::In 0.46.0

Locale::CLDR::Locales::Ko::Kore::Cn 0.46.0

Locale::CLDR::Locales::Ko::Kore::Kp 0.46.0

Locale::CLDR::Locales::Ko::Kore::Kr 0.46.0

Locale::CLDR::Locales::Ks::Arab::In 0.46.0

Locale::CLDR::Locales::Ks::Deva::In 0.46.0

Locale::CLDR::Locales::Ku::Latn::Tr 0.46.0

Locale::CLDR::Locales::Kw::Latn::Gb 0.46.0

Locale::CLDR::Locales::Ky::Cyrl::Kg 0.46.0

Locale::CLDR::Locales::Lb::Latn::Lu 0.46.0

Locale::CLDR::Locales::Lg::Latn::Ug 0.46.0

Locale::CLDR::Locales::Ln::Latn::Ao 0.46.0

Locale::CLDR::Locales::Ln::Latn::Cd 0.46.0

Locale::CLDR::Locales::Ln::Latn::Cf 0.46.0

Locale::CLDR::Locales::Ln::Latn::Cg 0.46.0

Locale::CLDR::Locales::Lo::Laoo::La 0.46.0

Locale::CLDR::Locales::Lt::Latn::Lt 0.46.0

Locale::CLDR::Locales::Lu::Latn::Cd 0.46.0

Locale::CLDR::Locales::Lv::Latn::Lv 0.46.0

Locale::CLDR::Locales::Mg::Latn::Mg 0.46.0

Locale::CLDR::Locales::Mi::Latn::Nz 0.46.0

Locale::CLDR::Locales::Mk::Cyrl::Mk 0.46.0

Locale::CLDR::Locales::Ml::Mlym::In 0.46.0

Locale::CLDR::Locales::Mn::Cyrl::Mn 0.46.0

Locale::CLDR::Locales::Mn::Mong::Cn 0.46.0

Locale::CLDR::Locales::Mn::Mong::Mn 0.46.0

Locale::CLDR::Locales::Mr::Deva::In 0.46.0

Locale::CLDR::Locales::Ms::Arab::Bn 0.46.0

Locale::CLDR::Locales::Ms::Arab::My 0.46.0

Locale::CLDR::Locales::Ms::Latn::Bn 0.46.0

Locale::CLDR::Locales::Ms::Latn::Id 0.46.0

Locale::CLDR::Locales::Ms::Latn::My 0.46.0

Locale::CLDR::Locales::Ms::Latn::Sg 0.46.0

Locale::CLDR::Locales::Mt::Latn::Mt 0.46.0

Locale::CLDR::Locales::My::Mymr::Mm 0.46.0

Locale::CLDR::Locales::Nb::Latn::No 0.46.0

Locale::CLDR::Locales::Nd::Latn::Zw 0.46.0

Locale::CLDR::Locales::Ne::Deva::In 0.46.0

Locale::CLDR::Locales::Ne::Deva::Np 0.46.0

Locale::CLDR::Locales::Nl::Latn::Be 0.46.0

Locale::CLDR::Locales::Nl::Latn::Nl 0.46.0

Locale::CLDR::Locales::Nl::Latn::Sr 0.46.0

Locale::CLDR::Locales::Nn::Latn::No 0.46.0

Locale::CLDR::Locales::Nr::Latn::Za 0.46.0

Locale::CLDR::Locales::Nv::Latn::Us 0.46.0

Locale::CLDR::Locales::Ny::Latn::Mw 0.46.0

Locale::CLDR::Locales::Oc::Latn::Es 0.46.0

Locale::CLDR::Locales::Oc::Latn::Fr 0.46.0

Locale::CLDR::Locales::Om::Latn::Et 0.46.0

Locale::CLDR::Locales::Om::Latn::Ke 0.46.0

Locale::CLDR::Locales::Or::Orya::In 0.46.0

Locale::CLDR::Locales::Os::Cyrl::Ge 0.46.0

Locale::CLDR::Locales::Os::Cyrl::Ru 0.46.0

Locale::CLDR::Locales::Pa::Arab::Pk 0.46.0

Locale::CLDR::Locales::Pa::Guru::In 0.46.0

Locale::CLDR::Locales::Pl::Latn::Pl 0.46.0

Locale::CLDR::Locales::Ps::Arab::Af 0.46.0

Locale::CLDR::Locales::Ps::Arab::Pk 0.46.0

Locale::CLDR::Locales::Pt::Latn::Ao 0.46.0

Locale::CLDR::Locales::Pt::Latn::Br 0.46.0

Locale::CLDR::Locales::Pt::Latn::Ch 0.46.0

Locale::CLDR::Locales::Pt::Latn::Cv 0.46.0

Locale::CLDR::Locales::Pt::Latn::Gq 0.46.0

Locale::CLDR::Locales::Pt::Latn::Gw 0.46.0

Locale::CLDR::Locales::Pt::Latn::Lu 0.46.0

Locale::CLDR::Locales::Pt::Latn::Mz 0.46.0

Locale::CLDR::Locales::Pt::Latn::Pt 0.46.0

Locale::CLDR::Locales::Pt::Latn::St 0.46.0

Locale::CLDR::Locales::Pt::Latn::Tl 0.46.0

Locale::CLDR::Locales::Qu::Latn::Bo 0.46.0

Locale::CLDR::Locales::Qu::Latn::Ec 0.46.0

Locale::CLDR::Locales::Qu::Latn::Pe 0.46.0

Locale::CLDR::Locales::Rm::Latn::Ch 0.46.0

Locale::CLDR::Locales::Rn::Latn::Bi 0.46.0

Locale::CLDR::Locales::Ro::Latn::Md 0.46.0

Locale::CLDR::Locales::Ro::Latn::Ro 0.46.0

Locale::CLDR::Locales::Ru::Cyrl::By 0.46.0

Locale::CLDR::Locales::Ru::Cyrl::Kg 0.46.0

Locale::CLDR::Locales::Ru::Cyrl::Kz 0.46.0

Locale::CLDR::Locales::Ru::Cyrl::Md 0.46.0

Locale::CLDR::Locales::Ru::Cyrl::Ru 0.46.0

Locale::CLDR::Locales::Ru::Cyrl::Ua 0.46.0

Locale::CLDR::Locales::Rw::Latn::Rw 0.46.0

Locale::CLDR::Locales::Sa::Deva::In 0.46.0

Locale::CLDR::Locales::Sc::Latn::It 0.46.0

Locale::CLDR::Locales::Sd::Arab::Pk 0.46.0

Locale::CLDR::Locales::Sd::Deva::In 0.46.0

Locale::CLDR::Locales::Se::Latn::Fi 0.46.0

Locale::CLDR::Locales::Se::Latn::No 0.46.0

Locale::CLDR::Locales::Se::Latn::Se 0.46.0

Locale::CLDR::Locales::Sg::Latn::Cf 0.46.0

Locale::CLDR::Locales::Si::Sinh::Lk 0.46.0

Locale::CLDR::Locales::Sk::Latn::Sk 0.46.0

Locale::CLDR::Locales::Sl::Latn::Si 0.46.0

Locale::CLDR::Locales::Sn::Latn::Zw 0.46.0

Locale::CLDR::Locales::So::Latn::Dj 0.46.0

Locale::CLDR::Locales::So::Latn::Et 0.46.0

Locale::CLDR::Locales::So::Latn::Ke 0.46.0

Locale::CLDR::Locales::So::Latn::So 0.46.0

Locale::CLDR::Locales::Sq::Latn::Al 0.46.0

Locale::CLDR::Locales::Sq::Latn::Mk 0.46.0

Locale::CLDR::Locales::Sr::Cyrl::Ba 0.46.0

Locale::CLDR::Locales::Sr::Cyrl::Me 0.46.0

Locale::CLDR::Locales::Sr::Cyrl::Rs 0.46.0

Locale::CLDR::Locales::Sr::Latn::Ba 0.46.0

Locale::CLDR::Locales::Sr::Latn::Me 0.46.0

Locale::CLDR::Locales::Sr::Latn::Rs 0.46.0

Locale::CLDR::Locales::Ss::Latn::Sz 0.46.0

Locale::CLDR::Locales::Ss::Latn::Za 0.46.0

Locale::CLDR::Locales::St::Latn::Ls 0.46.0

Locale::CLDR::Locales::St::Latn::Za 0.46.0

Locale::CLDR::Locales::Su::Latn::Id 0.46.0

Locale::CLDR::Locales::Sv::Latn::Fi 0.46.0

Locale::CLDR::Locales::Sv::Latn::Se 0.46.0

Locale::CLDR::Locales::Sw::Latn::Cd 0.46.0

Locale::CLDR::Locales::Sw::Latn::Ke 0.46.0

Locale::CLDR::Locales::Sw::Latn::Tz 0.46.0

Locale::CLDR::Locales::Sw::Latn::Ug 0.46.0

Locale::CLDR::Locales::Ta::Taml::In 0.46.0

Locale::CLDR::Locales::Ta::Taml::Lk 0.46.0

Locale::CLDR::Locales::Ta::Taml::My 0.46.0

Locale::CLDR::Locales::Ta::Taml::Sg 0.46.0

Locale::CLDR::Locales::Te::Telu::In 0.46.0

Locale::CLDR::Locales::Tg::Cyrl::Tj 0.46.0

Locale::CLDR::Locales::Th::Thai::Th 0.46.0

Locale::CLDR::Locales::Ti::Ethi::Er 0.46.0

Locale::CLDR::Locales::Ti::Ethi::Et 0.46.0

Locale::CLDR::Locales::Tk::Latn::Tm 0.46.0

Locale::CLDR::Locales::Tn::Latn::Bw 0.46.0

Locale::CLDR::Locales::Tn::Latn::Za 0.46.0

Locale::CLDR::Locales::To::Latn::To 0.46.0

Locale::CLDR::Locales::Tr::Latn::Cy 0.46.0

Locale::CLDR::Locales::Tr::Latn::Tr 0.46.0

Locale::CLDR::Locales::Ts::Latn::Za 0.46.0

Locale::CLDR::Locales::Tt::Cyrl::Ru 0.46.0

Locale::CLDR::Locales::Ug::Arab::Cn 0.46.0

Locale::CLDR::Locales::Uk::Cyrl::Ua 0.46.0

Locale::CLDR::Locales::Ur::Arab::In 0.46.0

Locale::CLDR::Locales::Ur::Arab::Pk 0.46.0

Locale::CLDR::Locales::Uz::Arab::Af 0.46.0

Locale::CLDR::Locales::Uz::Cyrl::Uz 0.46.0

Locale::CLDR::Locales::Uz::Latn::Uz 0.46.0

Locale::CLDR::Locales::Ve::Latn::Za 0.46.0

Locale::CLDR::Locales::Vi::Latn::Vn 0.46.0

Locale::CLDR::Locales::Wa::Latn::Be 0.46.0

Locale::CLDR::Locales::Wo::Latn::Sn 0.46.0

Locale::CLDR::Locales::Xh::Latn::Za 0.46.0

Locale::CLDR::Locales::Yi::Hebr::Ua 0.46.0

Locale::CLDR::Locales::Yo::Latn::Bj 0.46.0

Locale::CLDR::Locales::Yo::Latn::Ng 0.46.0

Locale::CLDR::Locales::Za::Latn::Cn 0.46.0

Locale::CLDR::Locales::Zh::Hans::Cn 0.46.0

Locale::CLDR::Locales::Zh::Hans::My 0.46.0

Locale::CLDR::Locales::Zh::Hans::Sg 0.46.0

Locale::CLDR::Locales::Zh::Hant::My 0.46.0

Locale::CLDR::Locales::Zh::Latn::Cn 0.46.0

Locale::CLDR::Locales::Zu::Latn::Za 0.46.0

Locale::CLDR::Locales::Agq::Latn::Cm 0.46.0

Locale::CLDR::Locales::Ann::Latn::Ng 0.46.0

Locale::CLDR::Locales::Apc::Arab::Sy 0.46.0

Locale::CLDR::Locales::Arn::Latn::Cl 0.46.0

Locale::CLDR::Locales::Asa::Latn::Tz 0.46.0

Locale::CLDR::Locales::Ast::Latn::Es 0.46.0

Locale::CLDR::Locales::Bal::Arab::Pk 0.46.0

Locale::CLDR::Locales::Bal::Latn::Pk 0.46.0

Locale::CLDR::Locales::Bas::Latn::Cm 0.46.0

Locale::CLDR::Locales::Bem::Latn::Zm 0.46.0

Locale::CLDR::Locales::Bew::Latn::Id 0.46.0

Locale::CLDR::Locales::Bez::Latn::Tz 0.46.0

Locale::CLDR::Locales::Bgc::Deva::In 0.46.0

Locale::CLDR::Locales::Bgn::Arab::Ae 0.46.0

Locale::CLDR::Locales::Bgn::Arab::Af 0.46.0

Locale::CLDR::Locales::Bgn::Arab::Ir 0.46.0

Locale::CLDR::Locales::Bgn::Arab::Om 0.46.0

Locale::CLDR::Locales::Bgn::Arab::Pk 0.46.0

Locale::CLDR::Locales::Bho::Deva::In 0.46.0

Locale::CLDR::Locales::Blo::Latn::Bj 0.46.0

Locale::CLDR::Locales::Blt::Tavt::Vn 0.46.0

Locale::CLDR::Locales::Brx::Deva::In 0.46.0

Locale::CLDR::Locales::Bss::Latn::Cm 0.46.0

Locale::CLDR::Locales::Byn::Ethi::Er 0.46.0

Locale::CLDR::Locales::Cad::Latn::Us 0.46.0

Locale::CLDR::Locales::Cch::Latn::Ng 0.46.0

Locale::CLDR::Locales::Ccp::Cakm::Bd 0.46.0

Locale::CLDR::Locales::Ccp::Cakm::In 0.46.0

Locale::CLDR::Locales::Ceb::Latn::Ph 0.46.0

Locale::CLDR::Locales::Cgg::Latn::Ug 0.46.0

Locale::CLDR::Locales::Cho::Latn::Us 0.46.0

Locale::CLDR::Locales::Chr::Cher::Us 0.46.0

Locale::CLDR::Locales::Cic::Latn::Us 0.46.0

Locale::CLDR::Locales::Ckb::Arab::Iq 0.46.0

Locale::CLDR::Locales::Ckb::Arab::Ir 0.46.0

Locale::CLDR::Locales::Csw::Cans::Ca 0.46.0

Locale::CLDR::Locales::Dav::Latn::Ke 0.46.0

Locale::CLDR::Locales::Dje::Latn::Ne 0.46.0

Locale::CLDR::Locales::Doi::Deva::In 0.46.0

Locale::CLDR::Locales::Dsb::Latn::De 0.46.0

Locale::CLDR::Locales::Dua::Latn::Cm 0.46.0

Locale::CLDR::Locales::Dyo::Latn::Sn 0.46.0

Locale::CLDR::Locales::Ebu::Latn::Ke 0.46.0

Locale::CLDR::Locales::En::Latn::001 0.46.0

Locale::CLDR::Locales::En::Latn::150 0.46.0

Locale::CLDR::Locales::Es::Latn::419 0.46.0

Locale::CLDR::Locales::Ewo::Latn::Cm 0.46.0

Locale::CLDR::Locales::Fil::Latn::Ph 0.46.0

Locale::CLDR::Locales::Frr::Latn::De 0.46.0

Locale::CLDR::Locales::Fur::Latn::It 0.46.0

Locale::CLDR::Locales::Gaa::Latn::Gh 0.46.0

Locale::CLDR::Locales::Gez::Ethi::Er 0.46.0

Locale::CLDR::Locales::Gez::Ethi::Et 0.46.0

Locale::CLDR::Locales::Gsw::Latn::Ch 0.46.0

Locale::CLDR::Locales::Gsw::Latn::Fr 0.46.0

Locale::CLDR::Locales::Gsw::Latn::Li 0.46.0

Locale::CLDR::Locales::Guz::Latn::Ke 0.46.0

Locale::CLDR::Locales::Haw::Latn::Us 0.46.0

Locale::CLDR::Locales::Hnj::Hmnp::Us 0.46.0

Locale::CLDR::Locales::Hsb::Latn::De 0.46.0

Locale::CLDR::Locales::Jgo::Latn::Cm 0.46.0

Locale::CLDR::Locales::Jmc::Latn::Tz 0.46.0

Locale::CLDR::Locales::Kaa::Cyrl::Uz 0.46.0

Locale::CLDR::Locales::Kaa::Latn::Uz 0.46.0

Locale::CLDR::Locales::Kab::Latn::Dz 0.46.0

Locale::CLDR::Locales::Kaj::Latn::Ng 0.46.0

Locale::CLDR::Locales::Kam::Latn::Ke 0.46.0

Locale::CLDR::Locales::Kcg::Latn::Ng 0.46.0

Locale::CLDR::Locales::Kde::Latn::Tz 0.46.0

Locale::CLDR::Locales::Kea::Latn::Cv 0.46.0

Locale::CLDR::Locales::Ken::Latn::Cm 0.46.0

Locale::CLDR::Locales::Kgp::Latn::Br 0.46.0

Locale::CLDR::Locales::Khq::Latn::Ml 0.46.0

Locale::CLDR::Locales::Kkj::Latn::Cm 0.46.0

Locale::CLDR::Locales::Kln::Latn::Ke 0.46.0

Locale::CLDR::Locales::Kok::Deva::In 0.46.0

Locale::CLDR::Locales::Kok::Latn::In 0.46.0

Locale::CLDR::Locales::Kpe::Latn::Gn 0.46.0

Locale::CLDR::Locales::Kpe::Latn::Lr 0.46.0

Locale::CLDR::Locales::Ksb::Latn::Tz 0.46.0

Locale::CLDR::Locales::Ksf::Latn::Cm 0.46.0

Locale::CLDR::Locales::Ksh::Latn::De 0.46.0

Locale::CLDR::Locales::Kxv::Deva::In 0.46.0

Locale::CLDR::Locales::Kxv::Latn::In 0.46.0

Locale::CLDR::Locales::Kxv::Orya::In 0.46.0

Locale::CLDR::Locales::Kxv::Telu::In 0.46.0

Locale::CLDR::Locales::Lag::Latn::Tz 0.46.0

Locale::CLDR::Locales::Lij::Latn::It 0.46.0

Locale::CLDR::Locales::Lkt::Latn::Us 0.46.0

Locale::CLDR::Locales::Lld::Latn::It 0.46.0

Locale::CLDR::Locales::Lmo::Latn::It 0.46.0

Locale::CLDR::Locales::Lrc::Arab::Iq 0.46.0

Locale::CLDR::Locales::Lrc::Arab::Ir 0.46.0

Locale::CLDR::Locales::Ltg::Latn::Lv 0.46.0

Locale::CLDR::Locales::Luo::Latn::Ke 0.46.0

Locale::CLDR::Locales::Luy::Latn::Ke 0.46.0

Locale::CLDR::Locales::Mai::Deva::In 0.46.0

Locale::CLDR::Locales::Mas::Latn::Ke 0.46.0

Locale::CLDR::Locales::Mas::Latn::Tz 0.46.0

Locale::CLDR::Locales::Mdf::Cyrl::Ru 0.46.0

Locale::CLDR::Locales::Mer::Latn::Ke 0.46.0

Locale::CLDR::Locales::Mfe::Latn::Mu 0.46.0

Locale::CLDR::Locales::Mgh::Latn::Mz 0.46.0

Locale::CLDR::Locales::Mgo::Latn::Cm 0.46.0

Locale::CLDR::Locales::Mhn::Latn::It 0.46.0

Locale::CLDR::Locales::Mic::Latn::Ca 0.46.0

Locale::CLDR::Locales::Mni::Beng::In 0.46.0

Locale::CLDR::Locales::Mni::Mtei::In 0.46.0

Locale::CLDR::Locales::Moh::Latn::Ca 0.46.0

Locale::CLDR::Locales::Mua::Latn::Cm 0.46.0

Locale::CLDR::Locales::Mus::Latn::Us 0.46.0

Locale::CLDR::Locales::Myv::Cyrl::Ru 0.46.0

Locale::CLDR::Locales::Mzn::Arab::Ir 0.46.0

Locale::CLDR::Locales::Naq::Latn::Na 0.46.0

Locale::CLDR::Locales::Nds::Latn::De 0.46.0

Locale::CLDR::Locales::Nds::Latn::Nl 0.46.0

Locale::CLDR::Locales::Nmg::Latn::Cm 0.46.0

Locale::CLDR::Locales::Nnh::Latn::Cm 0.46.0

Locale::CLDR::Locales::Nqo::Nkoo::Gn 0.46.0

Locale::CLDR::Locales::Nso::Latn::Za 0.46.0

Locale::CLDR::Locales::Nus::Latn::Ss 0.46.0

Locale::CLDR::Locales::Nyn::Latn::Ug 0.46.0

Locale::CLDR::Locales::Osa::Osge::Us 0.46.0

Locale::CLDR::Locales::Pcm::Latn::Ng 0.46.0

Locale::CLDR::Locales::Pis::Latn::Sb 0.46.0

Locale::CLDR::Locales::Prg::Latn::Pl 0.46.0

Locale::CLDR::Locales::Quc::Latn::Gt 0.46.0

Locale::CLDR::Locales::Raj::Deva::In 0.46.0

Locale::CLDR::Locales::Rhg::Rohg::Bd 0.46.0

Locale::CLDR::Locales::Rhg::Rohg::Mm 0.46.0

Locale::CLDR::Locales::Rif::Latn::Ma 0.46.0

Locale::CLDR::Locales::Rof::Latn::Tz 0.46.0

Locale::CLDR::Locales::Rwk::Latn::Tz 0.46.0

Locale::CLDR::Locales::Sah::Cyrl::Ru 0.46.0

Locale::CLDR::Locales::Saq::Latn::Ke 0.46.0

Locale::CLDR::Locales::Sat::Deva::In 0.46.0

Locale::CLDR::Locales::Sat::Olck::In 0.46.0

Locale::CLDR::Locales::Sbp::Latn::Tz 0.46.0

Locale::CLDR::Locales::Scn::Latn::It 0.46.0

Locale::CLDR::Locales::Sdh::Arab::Iq 0.46.0

Locale::CLDR::Locales::Sdh::Arab::Ir 0.46.0

Locale::CLDR::Locales::Seh::Latn::Mz 0.46.0

Locale::CLDR::Locales::Ses::Latn::Ml 0.46.0

Locale::CLDR::Locales::Shi::Latn::Ma 0.46.0

Locale::CLDR::Locales::Shi::Tfng::Ma 0.46.0

Locale::CLDR::Locales::Shn::Mymr::Mm 0.46.0

Locale::CLDR::Locales::Shn::Mymr::Th 0.46.0

Locale::CLDR::Locales::Sid::Latn::Et 0.46.0

Locale::CLDR::Locales::Skr::Arab::Pk 0.46.0

Locale::CLDR::Locales::Sma::Latn::No 0.46.0

Locale::CLDR::Locales::Sma::Latn::Se 0.46.0

Locale::CLDR::Locales::Smj::Latn::No 0.46.0

Locale::CLDR::Locales::Smj::Latn::Se 0.46.0

Locale::CLDR::Locales::Smn::Latn::Fi 0.46.0

Locale::CLDR::Locales::Sms::Latn::Fi 0.46.0

Locale::CLDR::Locales::Ssy::Latn::Er 0.46.0

Locale::CLDR::Locales::Syr::Syrc::Iq 0.46.0

Locale::CLDR::Locales::Syr::Syrc::Sy 0.46.0

Locale::CLDR::Locales::Szl::Latn::Pl 0.46.0

Locale::CLDR::Locales::Teo::Latn::Ke 0.46.0

Locale::CLDR::Locales::Teo::Latn::Ug 0.46.0

Locale::CLDR::Locales::Tig::Ethi::Er 0.46.0

Locale::CLDR::Locales::Tpi::Latn::Pg 0.46.0

Locale::CLDR::Locales::Trw::Arab::Pk 0.46.0

Locale::CLDR::Locales::Twq::Latn::Ne 0.46.0

Locale::CLDR::Locales::Tyv::Cyrl::Ru 0.46.0

Locale::CLDR::Locales::Tzm::Latn::Ma 0.46.0

Locale::CLDR::Locales::Vai::Latn::Lr 0.46.0

Locale::CLDR::Locales::Vai::Vaii::Lr 0.46.0

Locale::CLDR::Locales::Vec::Latn::It 0.46.0

Locale::CLDR::Locales::Vmw::Latn::Mz 0.46.0

Locale::CLDR::Locales::Vun::Latn::Tz 0.46.0

Locale::CLDR::Locales::Wae::Latn::Ch 0.46.0

Locale::CLDR::Locales::Wal::Ethi::Et 0.46.0

Locale::CLDR::Locales::Wbp::Latn::Au 0.46.0

Locale::CLDR::Locales::Xnr::Deva::In 0.46.0

Locale::CLDR::Locales::Xog::Latn::Ug 0.46.0

Locale::CLDR::Locales::Yav::Latn::Cm 0.46.0

Locale::CLDR::Locales::Yrl::Latn::Br 0.46.0

Locale::CLDR::Locales::Yrl::Latn::Co 0.46.0

Locale::CLDR::Locales::Yrl::Latn::Ve 0.46.0

Locale::CLDR::Locales::Yue::Hans::Cn 0.46.0

Locale::CLDR::Locales::Yue::Hant::Cn 0.46.0

Locale::CLDR::Locales::Zgh::Tfng::Ma 0.46.0


=cut

1;

